ChangeSet 1.2053, 2005/03/09 15:35:31-08:00, [EMAIL PROTECTED]

[PATCH] sysdev: fix the name of the list of drivers to be a sane name

Heh, "global_drivers" as a static...

Signed-off-by: Greg Kroah-Hartman <[EMAIL PROTECTED]>


 drivers/base/sys.c |   16 ++++++++--------
 1 files changed, 8 insertions(+), 8 deletions(-)


diff -Nru a/drivers/base/sys.c b/drivers/base/sys.c
--- a/drivers/base/sys.c        2005-03-09 16:28:17 -08:00
+++ b/drivers/base/sys.c        2005-03-09 16:28:17 -08:00
@@ -102,7 +102,7 @@
 EXPORT_SYMBOL_GPL(sysdev_class_unregister);
 
 
-static LIST_HEAD(global_drivers);
+static LIST_HEAD(sysdev_drivers);
 
 /**
  *     sysdev_driver_register - Register auxillary driver
@@ -112,7 +112,7 @@
  *     If @cls is valid, then @drv is inserted into @cls->drivers to be
  *     called on each operation on devices of that class. The refcount
  *     of @cls is incremented.
  *     Otherwise, @drv is inserted into global_drivers, and called for
  *     each device.
  */
 
@@ -130,7 +130,7 @@
                                drv->add(dev);
                }
        } else
-               list_add_tail(&drv->entry, &global_drivers);
+               list_add_tail(&drv->entry, &sysdev_drivers);
        up_write(&system_subsys.rwsem);
        return 0;
 }
@@ -199,7 +199,7 @@
                 */
 
                /* Notify global drivers */
-               list_for_each_entry(drv, &global_drivers, entry) {
+               list_for_each_entry(drv, &sysdev_drivers, entry) {
                        if (drv->add)
                                drv->add(sysdev);
                }
@@ -219,7 +219,7 @@
        struct sysdev_driver * drv;
 
        down_write(&system_subsys.rwsem);
-       list_for_each_entry(drv, &global_drivers, entry) {
+       list_for_each_entry(drv, &sysdev_drivers, entry) {
                if (drv->remove)
                        drv->remove(sysdev);
        }
@@ -268,7 +268,7 @@
                        pr_debug(" %s\n", kobject_name(&sysdev->kobj));
 
                        /* Call global drivers first. */
-                       list_for_each_entry(drv, &global_drivers, entry) {
+                       list_for_each_entry(drv, &sysdev_drivers, entry) {
                                if (drv->shutdown)
                                        drv->shutdown(sysdev);
                        }
@@ -319,7 +319,7 @@
                        pr_debug(" %s\n", kobject_name(&sysdev->kobj));
 
                        /* Call global drivers first. */
-                       list_for_each_entry(drv, &global_drivers, entry) {
+                       list_for_each_entry(drv, &sysdev_drivers, entry) {
                                if (drv->suspend)
                                        drv->suspend(sysdev, state);
                        }
@@ -375,7 +375,7 @@
                        }
 
                        /* Call global drivers. */
-                       list_for_each_entry(drv, &global_drivers, entry) {
+                       list_for_each_entry(drv, &sysdev_drivers, entry) {
                                if (drv->resume)
                                        drv->resume(sysdev);
                        }

-
@@ -112,7 +112,7 @@
  *     called on each operation on devices of that class. The refcount
  *     of @cls is incremented.
- *     Otherwise, @drv is inserted into global_drivers, and called for
+ *     Otherwise, @drv is inserted into sysdev_drivers, and called for
  *     each device.
  */
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to